==> prestashop_1.3.7.0.zip: prestashop/modules/statsbestcustomers/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_4f29d8c727dcf2022ac241cb96c31083'] = 'El recordset se devolvió vacío';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_eab2b4237a7cd89c309119e35f62d168'] = 'Mostrando';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8bf8854bebe108183caeb845c7676ae4'] = 'de';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_dff4bf10409100d989495c6d5486035e'] = 'apellido';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_04176f095283bc729f1e3926967e7034'] = 'Nombre';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_d7e637a6e9ff116de2fa89551240a94d'] = 'Visitas';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_1ff1b62d08d1195f073c6adac00f1894'] = 'Dinero enviado';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8b83489bd116cb60e2f348e9c63cd7f6'] = 'Mejores clientes';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cdc31cfb8cc370e79d854a2f82849dd2'] = 'Lista de los mejores clientes';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cb21e843b037359d0fb5b793fccf964f'] = 'Desarrolle la fidelidad de sus clientes';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_e1b9cd2cf691574ade4e2e1077b03441'] = 'Mantener un cliente satisfecho es más rentable que captar uno nuevo. Por lo tanto, es necesario ganarse su lealtad, para que vuelva a su tienda.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_7b6ac3f2cdb42a4462ff7ca3c4358f71'] = 'El boca a boca es uno de los  mejores medios de conseguir clientes satisfechos; un cliente satisfecho atrae nuevos clientes.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_410008089d5bb723438103a84d48a59c'] = 'Para alcanzar este objetivo usted puede organizar: ';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_3e788301a1b0ce341aa5ce15bc520545'] = 'Operaciones puntuales: recompensas comerciales (ofertas especiales personalizadas, producto o servicio ofrecidos), recompensas no comerciales (prioridad en el envío de un pedido o de un producto), recompensas pecuniarias (enlaces, cupones del descuento, reembolsos...)';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_f299b58558601a85c98a2d1d7867d523'] = 'Operaciones sostenibles: tarjetas clientes o puntos de fidelidad, que no sólo justifican la comunicación entre el comerciante y el cliente, pero también ofrecen ventajas a los clientes (ofertas, descuentos privados).';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_49c8045b620233da0fa2d7088b2cb1c9'] = 'Estas operaciones animan a sus clientes a comprar y también a volver a su tienda regularmente.';

==> prestashop_1.4.0.7.zip: prestashop/modules/statsbestcustomers/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_4f29d8c727dcf2022ac241cb96c31083'] = 'El recordset se devolvió vacío';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_eab2b4237a7cd89c309119e35f62d168'] = 'Mostrando';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8bf8854bebe108183caeb845c7676ae4'] = 'de';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_dff4bf10409100d989495c6d5486035e'] = 'apellido';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_04176f095283bc729f1e3926967e7034'] = 'Nombre';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_d7e637a6e9ff116de2fa89551240a94d'] = 'Visitas';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_57f32d7d0e6672cc2b60bc7a49f91453'] = 'Página vista';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_1ff1b62d08d1195f073c6adac00f1894'] = 'Dinero enviado';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_8b83489bd116cb60e2f348e9c63cd7f6'] = 'Mejores clientes';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cdc31cfb8cc370e79d854a2f82849dd2'] = 'Lista de los mejores clientes';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_998e4c5c80f27dec552e99dfed34889a'] = 'CSV Export';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_cb21e843b037359d0fb5b793fccf964f'] = 'Desarrolle la fidelidad de sus clientes';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_ddc52d619df96876824d6cdfa9dbd4a0'] = 'Mantener un cliente satisfecho es más rentable que captar uno nuevo. Por lo tanto, es necesario ganarse su lealtad, para que vuelva a su tienda.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_7b6ac3f2cdb42a4462ff7ca3c4358f71'] = 'El boca a boca es uno de los  mejores medios de conseguir clientes satisfechos; un cliente satisfecho atrae nuevos clientes.';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_410008089d5bb723438103a84d48a59c'] = 'Para alcanzar este objetivo usted puede organizar: ';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_3e788301a1b0ce341aa5ce15bc520545'] = 'Operaciones puntuales: recompensas comerciales (ofertas especiales personalizadas, producto o servicio ofrecidos), recompensas no comerciales (prioridad en el envío de un pedido o de un producto), recompensas pecuniarias (enlaces, cupones del descuento, reembolsos...)';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_f299b58558601a85c98a2d1d7867d523'] = 'Operaciones sostenibles: tarjetas clientes o puntos de fidelidad, que no sólo justifican la comunicación entre el comerciante y el cliente, pero también ofrecen ventajas a los clientes (ofertas, descuentos privados).';
$_MODULE['<{statsbestcustomers}prestashop>statsbestcustomers_49c8045b620233da0fa2d7088b2cb1c9'] = 'Estas operaciones animan a sus clientes a comprar y también a volver a su tienda regularmente.';
